'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var useIntl = require('use-intl');
var Link = require('next/link');
var React = require('react');
var router = require('next/router');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var Link__default = /*#__PURE__*/_interopDefaultLegacy(Link);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

// Reuse the legacy cookie name
// https://nextjs.org/docs/advanced-features/i18n-routing#leveraging-the-next_locale-cookie
var COOKIE_LOCALE_NAME = 'NEXT_LOCALE'; // Should take precedence over the cookie

function getCookieValueByName(name) {
  var value = "; " + document.cookie;
  var parts = value.split("; " + name + "=");

  if (parts.length === 2) {
    var _parts$pop;

    return (_parts$pop = parts.pop()) == null ? void 0 : _parts$pop.split(';').shift();
  } else {
    return undefined;
  }
}

function useLocale() {
  // Shortcut to read the locale from the cookie. This allows to read the
  // locale on the client side without using `NextIntlClientProvider`.
  if (typeof window !== 'undefined') {
    var locale = getCookieValueByName(COOKIE_LOCALE_NAME);
    if (locale) return locale;
  } // The condition never changes across runtime
  // eslint-disable-next-line react-hooks/rules-of-hooks


  return useIntl.useLocale();
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var _excluded$1 = ["href", "locale"];
function createLocalizedLinkComponent(useLocale) {
  /**
   * Wraps `next/link` and prefixes the `href` with the current locale.
   */
  function LocalizedLink(_ref, ref) {
    var href = _ref.href,
        locale = _ref.locale,
        rest = _objectWithoutPropertiesLoose(_ref, _excluded$1);

    var curLocale = useLocale();
    if (!locale) locale = curLocale;
    var localizedHref = '/' + locale;

    if (href !== '/') {
      localizedHref += href;
    }

    return React__default["default"].createElement(Link__default["default"], _extends({
      ref: ref,
      href: localizedHref
    }, rest));
  }

  return React.forwardRef(LocalizedLink);
}

var _excluded = ["children", "locale"];
function NextIntlClientProvider(_ref) {
  var children = _ref.children,
      locale = _ref.locale,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  var router$1;

  try {
    // Reading from context is practically ok to do conditionally
    // eslint-disable-next-line react-hooks/rules-of-hooks
    router$1 = router.useRouter();
  } catch (error) {// Calling `useRouter` is not supported in the app folder
  } // The router can be undefined if used in a context outside
  // of Next.js (e.g. unit tests, Storybook, ...)


  if (!locale && router$1) {
    locale = router$1.locale;
  }

  if (!locale) {
    throw new Error("Couldn't determine locale. Please pass an explicit `locale` prop the provider, or if you're using the `pages` folder, use internationalized routing (https://nextjs.org/docs/advanced-features/i18n-routing)." );
  }

  return React__default["default"].createElement(useIntl.IntlProvider, _extends({
    locale: locale
  }, rest), children);
}

var LocalizedLink = /*#__PURE__*/createLocalizedLinkComponent(useLocale); // Legacy export for compatibility

Object.defineProperty(exports, 'IntlError', {
  enumerable: true,
  get: function () { return useIntl.IntlError; }
});
Object.defineProperty(exports, 'IntlErrorCode', {
  enumerable: true,
  get: function () { return useIntl.IntlErrorCode; }
});
Object.defineProperty(exports, 'createIntl', {
  enumerable: true,
  get: function () { return useIntl.createIntl; }
});
Object.defineProperty(exports, 'createTranslator', {
  enumerable: true,
  get: function () { return useIntl.createTranslator; }
});
Object.defineProperty(exports, 'useIntl', {
  enumerable: true,
  get: function () { return useIntl.useIntl; }
});
Object.defineProperty(exports, 'useNow', {
  enumerable: true,
  get: function () { return useIntl.useNow; }
});
Object.defineProperty(exports, 'useTimeZone', {
  enumerable: true,
  get: function () { return useIntl.useTimeZone; }
});
Object.defineProperty(exports, 'useTranslations', {
  enumerable: true,
  get: function () { return useIntl.useTranslations; }
});
exports.LocalizedLink = LocalizedLink;
exports.NextIntlProvider = NextIntlClientProvider;
exports.useLocale = useLocale;
//# sourceMappingURL=next-intl.cjs.development.js.map
